==============
 REANA-Client
==============

.. image:: https://img.shields.io/pypi/pyversions/reana-client.svg
   :target: https://pypi.org/pypi/reana-client

.. image:: https://img.shields.io/travis/reanahub/reana-client.svg
   :target: https://travis-ci.org/reanahub/reana-client

.. image:: https://readthedocs.org/projects/reana-client/badge/?version=latest
   :target: https://reana-client.readthedocs.io/en/latest/?badge=latest

.. image:: https://img.shields.io/coveralls/reanahub/reana-client.svg
   :target: https://coveralls.io/r/reanahub/reana-client

.. image:: https://badges.gitter.im/Join%20Chat.svg
   :target: https://gitter.im/reanahub/reana?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge

.. image:: https://img.shields.io/github/license/reanahub/reana.svg
   :target: https://github.com/reanahub/reana-client/blob/master/LICENSE

About
-----

REANA-Client is a component of the `REANA <http://www.reana.io/>`_ reusable and
reproducible research data analysis platform. It provides a command-line tool
that allows researchers to submit, run, and manage their computational
workflows.

Features
--------

- seed workspace with input code and data
- run computational workflows on remote compute clouds
- list submitted workflows and enquire about their statuses
- download results of finished workflows

Useful links
------------

- `documentation <https://reana-client.readthedocs.io/>`_
- `releases <https://github.com/reanahub/reana-client/releases>`_
- `known issues <https://github.com/reanahub/reana-client/issues>`_
- `source code <https://github.com/reanahub/reana-client>`_

For more information about the REANA reusable analysis platform, please see the
`REANA project <http://www.reana.io>`_ home page and the general `REANA
documentation <http://reana.readthedocs.io/>`_ pages.
